# Extras Keys for swarmauri_core

This template set recognizes the following EXTRAS keys:

- RESOURCE_KIND
- PURPOSE
- DESCRIPTION
- REQUIREMENTS
- DEPENDENCIES
- BASE_FILE
- EXTERNAL_DOC_FILES
- MIXIN_FILES
- EXAMPLES
